==> unit-1.0.49-sources.jar: io/intino/goros/unit/box/ui/displays/items/TasksTableOperationsItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TasksTableOperationsItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Task, UnitBox> {
	public _32_4_02080536847 _32_4_02080536847;
	public TasksTableOperationsItem._32_4_02080536847. CommentsTrigger commentsTrigger;
	public TasksTableOperationsItem._32_4_02080536847. Urgent urgent;

    public TasksTableOperationsItem(UnitBox box) {
        super(box);
        id("a1390666099");
    }

    @Override
	public void init() {
		super.init();
		if (_32_4_02080536847 == null) _32_4_02080536847 = register(new _32_4_02080536847(box()).<_32_4_02080536847>id("a_1873177871").owner(TasksTableOperationsItem.this));
		if (_32_4_02080536847 != null) commentsTrigger = _32_4_02080536847.commentsTrigger;
		if (_32_4_02080536847 != null) urgent = _32_4_02080536847.urgent;
	}

	public class _32_4_02080536847 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TasksTableOperationsItem._32_4_02080536847. CommentsTrigger commentsTrigger;
		public TasksTableOperationsItem._32_4_02080536847. Urgent urgent;

		public _32_4_02080536847(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (commentsTrigger == null) commentsTrigger = register(new CommentsTrigger(box()).<CommentsTrigger>id("a_1801782934").owner(TasksTableOperationsItem.this));
			if (urgent == null) urgent = register(new Urgent(box()).<Urgent>id("a_1549400005").owner(TasksTableOperationsItem.this));
		}

		public class CommentsTrigger extends io.intino.alexandria.ui.displays.components.OpenPopover<io.intino.alexandria.ui.displays.notifiers.OpenPopoverNotifier, UnitBox>  {

			public CommentsTrigger(UnitBox box) {
				super(box);
				_title("Más información");
				_readonly(true);
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("MoreHoriz");
				 _triggerEvent(io.intino.alexandria.ui.displays.components.OpenPopover.TriggerEvent.MouseOver);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Urgent extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox>  {

			public Urgent(UnitBox box) {
				super(box);
				_title("Marcar/Desmarcar como urgente");
				_color("#ddd");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("Alarm");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/ui/displays/items/TasksTableOperationsItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TasksTableOperationsItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Task, UnitBox> {
	public _32_4_0349102519 _32_4_0349102519;
	public TasksTableOperationsItem._32_4_0349102519. CommentsTrigger commentsTrigger;
	public TasksTableOperationsItem._32_4_0349102519. Urgent urgent;

    public TasksTableOperationsItem(UnitBox box) {
        super(box);
        id("a1390666099");
    }

    @Override
	public void init() {
		super.init();
		if (_32_4_0349102519 == null) _32_4_0349102519 = register(new _32_4_0349102519(box()).<_32_4_0349102519>id("a2135520746").owner(TasksTableOperationsItem.this));
		if (_32_4_0349102519 != null) commentsTrigger = _32_4_0349102519.commentsTrigger;
		if (_32_4_0349102519 != null) urgent = _32_4_0349102519.urgent;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_32_4_0349102519 != null) _32_4_0349102519.unregister();
	}

	public class _32_4_0349102519 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TasksTableOperationsItem._32_4_0349102519. CommentsTrigger commentsTrigger;
		public TasksTableOperationsItem._32_4_0349102519. Urgent urgent;

		public _32_4_0349102519(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (commentsTrigger == null) commentsTrigger = register(new CommentsTrigger(box()).<CommentsTrigger>id("a_1801782934").owner(TasksTableOperationsItem.this));
			if (urgent == null) urgent = register(new Urgent(box()).<Urgent>id("a_1549400005").owner(TasksTableOperationsItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (commentsTrigger != null) commentsTrigger.unregister();
			if (urgent != null) urgent.unregister();
		}

		public class CommentsTrigger extends io.intino.alexandria.ui.displays.components.OpenPopover<io.intino.alexandria.ui.displays.notifiers.OpenPopoverNotifier, UnitBox>  {

			public CommentsTrigger(UnitBox box) {
				super(box);
				_title("Más información");
				_readonly(true);
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("MoreHoriz");
				 _triggerEvent(io.intino.alexandria.ui.displays.components.OpenPopover.TriggerEvent.MouseOver);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class Urgent extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox>  {

			public Urgent(UnitBox box) {
				super(box);
				_title("Marcar/Desmarcar como urgente");
				_color("#ddd");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("Alarm");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
